'subroutine that makes an equation output table.

'inputs:
'  tab  		table object (note this table object must already exist)
'  !row		row at which to start the output  (usually 1).   On exit will be set at final row number
'  coefs		coefficient vector
'  cov		covariance sym matrix
'  %coefnames  coefficient names
'  !df			Degree of Freedom correction

subroutine local maketable(table tab, scalar !row, vector coefs, sym cov, string %coefnames, scalar !df)
	'check sizes are ok
	if @rows(coefs) <> @rows(cov) then
		seterr "Coefficient vector not comparable with covariance matrix"
		return
	endif
	if @rows(coefs) <> @wcount(%coefnames) then
		seterr "Coefficient names not comparable with coefficient vector"
		return
	endif
	
	tab.setwidth(1) 19   'set column width for first column
	tab.setwidth(2) 10	
	tab.setwidth(3:4) 11
	tab.setwidth(5) 9
	
	tab.setlines(!row) +d
	!row = !row+1
	'add coefficient column headings
	tab(!row,1) = "Variable"
	tab(!row,2) = "Coefficient"
	tab(!row,3) = "Std. Error"
	tab(!row,4) = "z-Statistic"
	tab(!row,5) = "Prob.  "
	tab.setjust(!row, 2, !row, 5) right
	!row = !row + 1
	tab.setlines(!row) +d
	!row = !row+1
	
	'row headings
	!temprow = !row
	for !i = 1 to @wcount(%coefnames)
		tab(!temprow,1) = @upper(@word(%coefnames,!i))
		!temprow = !temprow+1
	next
	
	'coefficients etc..
	for !i=1 to @wcount(%coefnames)  
		!coef = coefs(!i)
		!covar = @sqrt(cov(!i,!i))
		!tstat = !coef/!covar
		'!pvalue = {%dist}(!tstat,!df)
		!pvalue = 2*(1-@cnorm(@abs(!tstat)))
		tab(!row ,2) = !coef
		tab(!row,3) = !covar
		tab(!row,4) = !tstat
		tab(!row,5) = !pvalue
		tab.setformat(!row,5) "f.4"
		tab.setjust(!row, 2, !row, 5) right
		!row = !row + 1
	next
	tab.setlines(!row) +d
	!row=  !row+1
		
endsub
